@@ -161,6 +161,11 @@ public:
      */
     Q_PROPERTY(std::vector<KPublicTransport::Feature> features READ features)
 
+    /** The best available icon to represent this journey section.
+     *  Can be a qrc: or file: URL or an XDG icon name.
+     */
+    Q_PROPERTY(QString iconName READ iconName STORED false)
+
 public:
     [[nodiscard]] bool hasExpectedDepartureTime() const;
     [[nodiscard]] int departureDelay() const;
@@ -246,6 +251,13 @@ public:
     [[nodiscard]] std::vector<KPublicTransport::Feature>&& takeFeatures();
     void setFeatures(std::vector<KPublicTransport::Feature> &&features);
 
+    [[nodiscard]] QString iconName() const;
+
+    /** Icon representing the journey section mode @p mode.
+     *  Can be a qrc: or file: URL or an XDG icon name.
+     */
+    Q_INVOKABLE [[nodiscard]] static QString modeIconName(KPublicTransport::JourneySection::Mode mode);
+
 private:
     [[nodiscard]] QVariantList intermediateStopsVariant() const;
     [[nodiscard]] QVariantList loadInformationVariant() const;
@@ -290,6 +302,15 @@ class KPUBLICTRANSPORT_EXPORT Journey
     /** Worst disruption effect of any of the journey sections. */
     Q_PROPERTY(KPublicTransport::Disruption::Effect disruptionEffect READ disruptionEffect STORED false)
 
+    /** Total travelled distance of the entire journey in meter.
+     *  That is, the sum of the distances of all sections.
+     */
+    Q_PROPERTY(int distance READ distance STORED false)
+    /** Total CO2 emissions for the entire journey in gram.
+     *  That is, the sum of the emissions of all sections.
+     */
+    Q_PROPERTY(int co2Emission READ co2Emission STORED false)
+
 public:
     /** The journey sections. */
     [[nodiscard]] const std::vector<JourneySection>& sections() const;
@@ -312,6 +333,9 @@ public:
     [[nodiscard]] int numberOfChanges() const;
     [[nodiscard]] Disruption::Effect disruptionEffect() const;
 
+    [[nodiscard]] int distance() const;
+    [[nodiscard]] int co2Emission() const;
+
     /** Augment line meta data.
      *  @param download if set to @p true, trigger the download of locally missing assets.
      */
