@@ -7,7 +7,6 @@
 #include "manager.h"
 #include "assetrepository_p.h"
 #include "backends/srbijavozbackend.h"
-#include "backends/zpcgbackend.h"
 #include "journeyreply.h"
 #include "journeyrequest.h"
 #include "requestcontext_p.h"
@@ -23,8 +22,6 @@
 #include "datatypes/backend_p.h"
 #include "datatypes/disruption.h"
 #include "datatypes/json_p.h"
-#include "datatypes/platform.h"
-#include "datatypes/vehicle.h"
 #include "geo/geojson_p.h"
 
 #include <KPublicTransport/Journey>
@@ -39,6 +36,7 @@
 #include "backends/hafasquerybackend.h"
 #include "backends/ivvassbackend.h"
 #include "backends/motisbackend.h"
+#include "backends/motis2backend.h"
 #include "backends/navitiabackend.h"
 #include "backends/oebbbackend.h"
 #include "backends/openjourneyplannerbackend.h"
@@ -204,10 +202,10 @@ std::unique_ptr<AbstractBackend> ManagerPrivate::loadNetwork(const QJsonObject &
         IvvAssBackend,
         OpenJourneyPlannerBackend,
         MotisBackend,
+        Motis2Backend,
         GBFSBackend,
         AccessibilityCloudBackend,
         LTGLinkBackend,
-        ZPCGBackend,
         SrbijavozBackend
     >(type, obj);
 }
@@ -446,6 +444,7 @@ bool ManagerPrivate::queryStopover(const AbstractBackend *backend, const Stopove
         qCDebug(Log) << "Backend needs location query first:" << backend->backendId();
         LocationRequest locReq(req.stop());
         locReq.setTypes(Location::Stop); // Stopover can never refer to other location types
+        locReq.setMaximumDistance(250);
         resolveLocation(std::move(locReq), backend, [reply, req, backend, this](const Location &loc) {
             const auto depLoc = Location::merge(req.stop(), loc);
             auto depRequest = req;
